@@ -94,10 +94,6 @@
 #include <glib/gi18n-lib.h>
 #include <locale.h>
 
-#ifdef USE_GDKPIXBUF
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#endif
-
 #include "clutter-actor.h"
 #include "clutter-backend-private.h"
 #include "clutter-debug.h"
@@ -113,8 +109,8 @@
 #include "clutter-stage-private.h"
 #include "clutter-version.h" 	/* For flavour define */
 
-#include "cogl/cogl.h"
-#include "pango/cogl-pango.h"
+#include <cogl/cogl.h>
+#include <cogl-pango/cogl-pango.h>
 
 #include "cally.h" /* For accessibility support */
 
@@ -169,7 +165,8 @@ static const GDebugKey clutter_debug_keys[] = {
   { "shader", CLUTTER_DEBUG_SHADER },
   { "multistage", CLUTTER_DEBUG_MULTISTAGE },
   { "animation", CLUTTER_DEBUG_ANIMATION },
-  { "layout", CLUTTER_DEBUG_LAYOUT }
+  { "layout", CLUTTER_DEBUG_LAYOUT },
+  { "clipping", CLUTTER_DEBUG_CLIPPING }
 };
 #endif /* CLUTTER_ENABLE_DEBUG */
 
@@ -306,14 +303,18 @@ clutter_get_motion_events_enabled (void)
   return context->motion_events_per_actor;
 }
 
-static inline ClutterActor *
-_clutter_actor_get_by_id (guint32 actor_id)
+ClutterActor *
+_clutter_get_actor_by_id (ClutterStage *stage,
+                          guint32       actor_id)
 {
-  ClutterMainContext *context = _clutter_context_get_default ();
+  if (stage == NULL)
+    {
+      ClutterMainContext *context = _clutter_context_get_default ();
 
-  g_assert (context->id_pool != NULL);
+      return _clutter_id_pool_lookup (context->id_pool, actor_id);
+    }
 
-  return _clutter_id_pool_lookup (context->id_pool, actor_id);
+  return _clutter_stage_get_actor_by_pick_id (stage, actor_id);
 }
 
 void
@@ -387,7 +388,7 @@ _clutter_id_to_color (guint         id_,
     }
 }
 
-static inline guint
+guint
 _clutter_pixel_to_id (guchar pixel[4])
 {
   ClutterMainContext *ctx;
@@ -435,258 +436,6 @@ _clutter_pixel_to_id (guchar pixel[4])
   return retval;
 }
 
-#ifdef USE_GDKPIXBUF
-static void
-pixbuf_free (guchar   *pixels,
-             gpointer  data)
-{
-  g_free (pixels);
-}
-#endif
-
-static void
-read_pixels_to_file (char *filename_stem,
-                     int   x,
-                     int   y,
-                     int   width,
-                     int   height)
-{
-#ifdef USE_GDKPIXBUF
-  GLubyte *data;
-  GdkPixbuf *pixbuf;
-  static int read_count = 0;
-
-  data = g_malloc (4 * width * height);
-  cogl_read_pixels (x, y, width, height,
-                    COGL_READ_PIXELS_COLOR_BUFFER,
-                    COGL_PIXEL_FORMAT_RGB_888,
-                    data);
-  pixbuf = gdk_pixbuf_new_from_data (data,
-                                     GDK_COLORSPACE_RGB,
-                                     FALSE, /* has alpha */
-                                     8, /* bits per sample */
-                                     width, /* width */
-                                     height, /* height */
-                                     width * 3, /* rowstride */
-                                     pixbuf_free, /* callback to free data */
-                                     NULL); /* callback data */
-  if (pixbuf)
-    {
-      char *filename = g_strdup_printf ("%s-%05d.png",
-                                        filename_stem,
-                                        read_count);
-      GError *error = NULL;
-
-      if (!gdk_pixbuf_save (pixbuf, filename, "png", &error, NULL))
-        {
-          g_warning ("Failed to save pick buffer to file %s: %s",
-                     filename, error->message);
-          g_error_free (error);
-        }
-
-      g_free (filename);
-      g_object_unref (pixbuf);
-      read_count++;
-    }
-#else /* !USE_GDKPIXBUF */
-  {
-    static gboolean seen = FALSE;
-
-    if (!seen)
-      {
-        g_warning ("dumping buffers to an image isn't supported on platforms "
-                   "without gdk pixbuf support\n");
-        seen = TRUE;
-      }
-  }
-#endif /* USE_GDKPIXBUF */
-}
-
-ClutterActor *
-_clutter_do_pick (ClutterStage   *stage,
-		  gint            x,
-		  gint            y,
-		  ClutterPickMode mode)
-{
-  ClutterMainContext *context;
-  guchar pixel[4] = { 0xff, 0xff, 0xff, 0xff };
-  CoglColor stage_pick_id;
-  guint32 id_;
-  GLboolean dither_was_on;
-  ClutterActor *actor;
-  gboolean is_clipped;
-  CLUTTER_STATIC_COUNTER (do_pick_counter,
-                          "_clutter_do_pick counter",
-                          "Increments for each full pick run",
-                          0 /* no application private data */);
-  CLUTTER_STATIC_TIMER (pick_timer,
-                        "Mainloop", /* parent */
-                        "Picking",
-                        "The time spent picking",
-                        0 /* no application private data */);
-  CLUTTER_STATIC_TIMER (pick_clear,
-                        "Picking", /* parent */
-                        "Stage clear (pick)",
-                        "The time spent clearing stage for picking",
-                        0 /* no application private data */);
-  CLUTTER_STATIC_TIMER (pick_paint,
-                        "Picking", /* parent */
-                        "Painting actors (pick mode)",
-                        "The time spent painting actors in pick mode",
-                        0 /* no application private data */);
-  CLUTTER_STATIC_TIMER (pick_read,
-                        "Picking", /* parent */
-                        "Read Pixels",
-                        "The time spent issuing a read pixels",
-                        0 /* no application private data */);
-
-  g_return_val_if_fail (CLUTTER_IS_STAGE (stage), NULL);
-
-  if (G_UNLIKELY (clutter_pick_debug_flags & CLUTTER_DEBUG_NOP_PICKING))
-    return CLUTTER_ACTOR (stage);
-
-#ifdef CLUTTER_ENABLE_PROFILE
-  if (clutter_profile_flags & CLUTTER_PROFILE_PICKING_ONLY)
-    _clutter_profile_resume ();
-#endif /* CLUTTER_ENABLE_PROFILE */
-
-  CLUTTER_COUNTER_INC (_clutter_uprof_context, do_pick_counter);
-  CLUTTER_TIMER_START (_clutter_uprof_context, pick_timer);
-
-  context = _clutter_context_get_default ();
-
-  /* It's possible that we currently have a static scene and have renderered a
-   * full, unclipped pick buffer. If so we can simply continue to read from
-   * this cached buffer until the scene next changes. */
-  if (_clutter_stage_get_pick_buffer_valid (stage, mode))
-    {
-      CLUTTER_TIMER_START (_clutter_uprof_context, pick_read);
-      cogl_read_pixels (x, y, 1, 1,
-                        COGL_READ_PIXELS_COLOR_BUFFER,
-                        COGL_PIXEL_FORMAT_RGBA_8888_PRE,
-                        pixel);
-      CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_read);
-
-      CLUTTER_NOTE (PICK, "Reusing pick buffer from previous render to fetch "
-                    "actor at %i,%i", x, y);
-
-      /* FIXME: This is a lazy copy and paste of the logic at the end of this
-       * function used when we actually do a pick render. It should be
-       * consolidated somehow.
-       */
-      if (pixel[0] == 0xff && pixel[1] == 0xff && pixel[2] == 0xff)
-        {
-          actor = CLUTTER_ACTOR (stage);
-          goto result;
-        }
-
-      id_ = _clutter_pixel_to_id (pixel);
-      actor = _clutter_actor_get_by_id (id_);
-      goto result;
-    }
-
-  _clutter_stage_increment_picks_per_frame_counter (stage);
-
-  _clutter_backend_ensure_context (context->backend, stage);
-
-  /* needed for when a context switch happens */
-  _clutter_stage_maybe_setup_viewport (stage);
-
-  /* If we are seeing multiple picks per frame that means the scene is static
-   * so we promote to doing a non-scissored pick render so that all subsequent
-   * picks for the same static scene won't require additional renders */
-  if (_clutter_stage_get_picks_per_frame_counter (stage) < 2)
-    {
-      if (G_LIKELY (!(clutter_pick_debug_flags &
-                      CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
-        cogl_clip_push_window_rectangle (x, y, 1, 1);
-      is_clipped = TRUE;
-    }
-  else
-    is_clipped = FALSE;
-
-  CLUTTER_NOTE (PICK, "Performing %s pick at %i,%i",
-                is_clipped ? "clippped" : "full", x, y);
-
-  cogl_disable_fog ();
-  cogl_color_init_from_4ub (&stage_pick_id, 255, 255, 255, 255);
-  CLUTTER_TIMER_START (_clutter_uprof_context, pick_clear);
-  cogl_clear (&stage_pick_id,
-	      COGL_BUFFER_BIT_COLOR |
-	      COGL_BUFFER_BIT_DEPTH);
-  CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_clear);
-
-  /* Disable dithering (if any) when doing the painting in pick mode */
-  dither_was_on = glIsEnabled (GL_DITHER);
-  if (dither_was_on)
-    glDisable (GL_DITHER);
-
-  /* Render the entire scence in pick mode - just single colored silhouette's
-   * are drawn offscreen (as we never swap buffers)
-  */
-  CLUTTER_TIMER_START (_clutter_uprof_context, pick_paint);
-  context->pick_mode = mode;
-  _clutter_stage_do_paint (stage, NULL);
-  context->pick_mode = CLUTTER_PICK_NONE;
-  CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_paint);
-
-  if (is_clipped)
-    {
-      if (G_LIKELY (!(clutter_pick_debug_flags &
-                      CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
-        cogl_clip_pop ();
-
-      _clutter_stage_set_pick_buffer_valid (stage, FALSE, -1);
-    }
-  else
-    _clutter_stage_set_pick_buffer_valid (stage, TRUE, mode);
-
-  /* Read the color of the screen co-ords pixel. RGBA_8888_PRE is used
-     even though we don't care about the alpha component because under
-     GLES this is the only format that is guaranteed to work so Cogl
-     will end up having to do a conversion if any other format is
-     used. The format is requested as pre-multiplied because Cogl
-     assumes that all pixels in the framebuffer are premultiplied so
-     it avoids a conversion. */
-  CLUTTER_TIMER_START (_clutter_uprof_context, pick_read);
-  cogl_read_pixels (x, y, 1, 1,
-                    COGL_READ_PIXELS_COLOR_BUFFER,
-                    COGL_PIXEL_FORMAT_RGBA_8888_PRE,
-                    pixel);
-  CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_read);
-
-  if (G_UNLIKELY (clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
-    {
-      read_pixels_to_file ("pick-buffer", 0, 0,
-                           clutter_actor_get_width (CLUTTER_ACTOR (stage)),
-                           clutter_actor_get_height (CLUTTER_ACTOR (stage)));
-    }
-
-  /* Restore whether GL_DITHER was enabled */
-  if (dither_was_on)
-    glEnable (GL_DITHER);
-
-  if (pixel[0] == 0xff && pixel[1] == 0xff && pixel[2] == 0xff)
-    {
-      actor = CLUTTER_ACTOR (stage);
-      goto result;
-    }
-
-  id_ = _clutter_pixel_to_id (pixel);
-  actor = _clutter_actor_get_by_id (id_);
-
-result:
-
-  CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_timer);
-
-#ifdef CLUTTER_ENABLE_PROFILE
-  if (clutter_profile_flags & CLUTTER_PROFILE_PICKING_ONLY)
-    _clutter_profile_suspend ();
-#endif
-
-  return actor;
-}
-
 static CoglPangoFontMap *
 clutter_context_get_pango_fontmap (void)
 {
@@ -915,19 +664,12 @@ clutter_main (void)
   loop = g_main_loop_new (NULL, TRUE);
   main_loops = g_slist_prepend (main_loops, loop);
 
-#ifdef HAVE_CLUTTER_FRUITY
-  /* clutter fruity creates an application that forwards events and manually
-   * spins the mainloop
-   */
-  clutter_fruity_main ();
-#else
   if (g_main_loop_is_running (main_loops->data))
     {
       clutter_threads_leave ();
       g_main_loop_run (loop);
       clutter_threads_enter ();
     }
-#endif
 
   main_loops = g_slist_remove (main_loops, loop);
 
@@ -1656,14 +1398,9 @@ pre_parse_hook (GOptionContext  *context,
   if (env_string)
     clutter_disable_mipmap_text = TRUE;
 
-#ifdef HAVE_CLUTTER_FRUITY
-  /* we always enable fuzzy picking in the "fruity" backend */
-  clutter_use_fuzzy_picking = TRUE;
-#else
   env_string = g_getenv ("CLUTTER_FUZZY_PICK");
   if (env_string)
     clutter_use_fuzzy_picking = TRUE;
-#endif /* HAVE_CLUTTER_FRUITY */
 
   return _clutter_backend_pre_parse (backend, error);
 }
@@ -2481,9 +2218,9 @@ _clutter_process_event_details (ClutterActor        *stage,
                 {
                   CLUTTER_NOTE (EVENT, "No device found: picking");
 
-                  actor = _clutter_do_pick (CLUTTER_STAGE (stage),
-                                            x, y,
-                                            CLUTTER_PICK_REACTIVE);
+                  actor = _clutter_stage_do_pick (CLUTTER_STAGE (stage),
+                                                  x, y,
+                                                  CLUTTER_PICK_REACTIVE);
                 }
 
               if (actor == NULL)
@@ -2563,11 +2300,13 @@ _clutter_process_event (ClutterEvent *event)
  *   The returned actor does not have its reference count increased.
  *
  * Since: 0.6
+ *
+ * Deprecated: 1.8: The id is not used any longer.
  */
 ClutterActor *
 clutter_get_actor_by_gid (guint32 id_)
 {
-  return _clutter_actor_get_by_id (id_);
+  return _clutter_get_actor_by_id (NULL, id_);
 }
 
 void
@@ -3289,7 +3028,7 @@ _clutter_context_release_id (guint32 id_)
 {
   ClutterMainContext *context = _clutter_context_get_default ();
 
-  _clutter_id_pool_remove (context->id_pool, id_);
+  return _clutter_id_pool_remove (context->id_pool, id_);
 }
 
 void
