@@ -30,7 +30,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include "pango/cogl-pango.h"
+#include <cogl-pango/cogl-pango.h>
 
 #include "clutter-backend.h"
 #include "clutter-effect.h"
@@ -46,12 +46,6 @@ G_BEGIN_DECLS
 
 typedef struct _ClutterMainContext      ClutterMainContext;
 
-#define _clutter_notify_by_pspec(obj, pspec) \
-  g_object_notify_by_pspec ((obj), (pspec))
-
-#define _clutter_object_class_install_properties(oclass, n_pspecs, pspecs) \
-  g_object_class_install_properties ((oclass), (n_pspecs), (pspecs))
-
 #define CLUTTER_REGISTER_VALUE_TRANSFORM_TO(TYPE_TO,func)             { \
   g_value_register_transform_func (g_define_type_id, TYPE_TO, func);    \
 }
@@ -200,13 +194,11 @@ const gchar *_clutter_gettext (const gchar *str);
 gboolean      _clutter_feature_init (GError **error);
 
 /* Picking code */
-ClutterActor *_clutter_do_pick (ClutterStage    *stage,
-				gint             x,
-				gint             y,
-				ClutterPickMode  mode);
-
-void          _clutter_id_to_color (guint id,
-                                    ClutterColor *col);
+guint           _clutter_pixel_to_id            (guchar        pixel[4]);
+void            _clutter_id_to_color            (guint         id,
+                                                 ClutterColor *col);
+ClutterActor *  _clutter_get_actor_by_id        (ClutterStage *stage,
+                                                 guint32       actor_id);
 
 /* use this function as the accumulator if you have a signal with
  * a G_TYPE_BOOLEAN return value; this will stop the emission as
@@ -227,11 +219,25 @@ GType _clutter_layout_manager_get_child_meta_type (ClutterLayoutManager *manager
 
 void  _clutter_util_fully_transform_vertices (const CoglMatrix    *modelview,
                                               const CoglMatrix    *projection,
-                                              const int           *viewport,
+                                              const float         *viewport,
                                               const ClutterVertex *vertices_in,
                                               ClutterVertex       *vertices_out,
                                               int                  n_vertices);
 
+typedef struct _ClutterPlane
+{
+  CoglVector3 v0;
+  CoglVector3 n;
+} ClutterPlane;
+
+typedef enum _ClutterCullResult
+{
+  CLUTTER_CULL_RESULT_UNKNOWN,
+  CLUTTER_CULL_RESULT_IN,
+  CLUTTER_CULL_RESULT_OUT,
+  CLUTTER_CULL_RESULT_PARTIAL
+} ClutterCullResult;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_PRIVATE_H__ */
