@@ -159,9 +159,9 @@ clutter_snap_constraint_update_allocation (ClutterConstraint *constraint,
 
     case CLUTTER_SNAP_EDGE_RIGHT:
       if (self->from_edge == CLUTTER_SNAP_EDGE_RIGHT)
-        allocation->x2 = source_x + source_width + self->offset;
+        allocation->x2 = source_x + source_height + self->offset;
       else if (self->from_edge == CLUTTER_SNAP_EDGE_LEFT)
-        allocation->x1 = source_x + source_width + self->offset;
+        allocation->x1 = source_x + source_height + self->offset;
       else
         warn_horizontal_edge ("right", self->actor, self->source);
       break;
@@ -464,7 +464,7 @@ clutter_snap_constraint_set_source (ClutterSnapConstraint *constraint,
         clutter_actor_queue_relayout (constraint->actor);
     }
 
-  _clutter_notify_by_pspec (G_OBJECT (constraint), obj_props[PROP_SOURCE]);
+  g_object_notify_by_pspec (G_OBJECT (constraint), obj_props[PROP_SOURCE]);
 }
 
 /**
@@ -513,7 +513,7 @@ clutter_snap_constraint_set_edges (ClutterSnapConstraint *constraint,
   if (constraint->from_edge != from_edge)
     {
       constraint->from_edge = from_edge;
-      _clutter_notify_by_pspec (G_OBJECT (constraint),
+      g_object_notify_by_pspec (G_OBJECT (constraint),
                                 obj_props[PROP_FROM_EDGE]);
       from_changed = TRUE;
     }
@@ -521,7 +521,7 @@ clutter_snap_constraint_set_edges (ClutterSnapConstraint *constraint,
   if (constraint->to_edge != to_edge)
     {
       constraint->to_edge = to_edge;
-      _clutter_notify_by_pspec (G_OBJECT (constraint),
+      g_object_notify_by_pspec (G_OBJECT (constraint),
                                 obj_props[PROP_TO_EDGE]);
       to_changed = TRUE;
     }
@@ -582,7 +582,7 @@ clutter_snap_constraint_set_offset (ClutterSnapConstraint *constraint,
   if (constraint->actor != NULL)
     clutter_actor_queue_relayout (constraint->actor);
 
-  _clutter_notify_by_pspec (G_OBJECT (constraint), obj_props[PROP_OFFSET]);
+  g_object_notify_by_pspec (G_OBJECT (constraint), obj_props[PROP_OFFSET]);
 }
 
 /**
