@@ -409,6 +409,14 @@ clutter_texture_allocate (ClutterActor           *self,
     clutter_actor_allocate_preferred_size (priv->fbo_source, flags);
 }
 
+static gboolean
+clutter_texture_has_overlaps (ClutterActor *self)
+{
+  /* Textures never need an offscreen redirect because there are never
+     any overlapping primitives */
+  return FALSE;
+}
+
 static void
 set_viewport_with_buffer_under_fbo_source (ClutterActor *fbo_source,
                                            int viewport_width,
@@ -980,6 +988,7 @@ clutter_texture_class_init (ClutterTextureClass *klass)
   actor_class->get_paint_volume = clutter_texture_get_paint_volume;
   actor_class->realize          = clutter_texture_realize;
   actor_class->unrealize        = clutter_texture_unrealize;
+  actor_class->has_overlaps     = clutter_texture_has_overlaps;
 
   actor_class->get_preferred_width  = clutter_texture_get_preferred_width;
   actor_class->get_preferred_height = clutter_texture_get_preferred_height;
@@ -1517,7 +1526,7 @@ clutter_texture_set_cogl_texture (ClutterTexture  *texture,
   /* If resized actor may need resizing but paint() will do this */
   clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
 
-  _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_COGL_TEXTURE]);
+  g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_COGL_TEXTURE]);
 }
 
 static gboolean
@@ -2066,7 +2075,7 @@ clutter_texture_set_from_file (ClutterTexture *texture,
 
   g_signal_emit (texture, texture_signals[LOAD_FINISHED], 0, NULL);
 
-  _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILENAME]);
+  g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILENAME]);
 
   return TRUE;
 }
@@ -2114,7 +2123,7 @@ clutter_texture_set_filter_quality (ClutterTexture        *texture,
 
       clutter_actor_queue_redraw (CLUTTER_ACTOR (texture));
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILTER_QUALITY]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_FILTER_QUALITY]);
     }
 }
 
@@ -2725,7 +2734,7 @@ clutter_texture_set_sync_size (ClutterTexture *texture,
 
       clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_SYNC_SIZE]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_SYNC_SIZE]);
     }
 }
 
@@ -2777,7 +2786,7 @@ clutter_texture_set_repeat (ClutterTexture *texture,
     {
       priv->repeat_x = repeat_x;
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_X]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_X]);
 
       changed = TRUE;
     }
@@ -2786,7 +2795,7 @@ clutter_texture_set_repeat (ClutterTexture *texture,
     {
       priv->repeat_y = repeat_y;
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_Y]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_REPEAT_Y]);
 
       changed = TRUE;
     }
@@ -2880,7 +2889,7 @@ clutter_texture_set_keep_aspect_ratio (ClutterTexture *texture,
 
       clutter_actor_queue_relayout (CLUTTER_ACTOR (texture));
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_KEEP_ASPECT_RATIO]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_KEEP_ASPECT_RATIO]);
     }
 }
 
@@ -2935,8 +2944,8 @@ clutter_texture_set_load_async (ClutterTexture *texture,
 
       priv->load_async_set = load_async;
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
     }
 }
 
@@ -2993,8 +3002,8 @@ clutter_texture_set_load_data_async (ClutterTexture *texture,
 
       priv->load_async_set = load_async;
 
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
-      _clutter_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_ASYNC]);
+      g_object_notify_by_pspec (G_OBJECT (texture), obj_props[PROP_LOAD_DATA_ASYNC]);
     }
 }
 
